@@ -1,7 +1,8 @@
-# pylint: disable=missing-docstring
-#
-# Custom exception types used throughout the library. All exceptions derive
-# from GMTError.
+"""
+Custom exception types used throughout the library.
+
+All exceptions derive from GMTError.
+"""
 
 
 class GMTError(Exception):
@@ -44,3 +45,9 @@ class GMTVersionError(GMTError):
     """
     Raised when an incompatible version of GMT is being used.
     """
+
+
+class GMTImageComparisonFailure(AssertionError):
+    """
+    Raised when a comparison between two images fails.
+    """
