@@ -2,18 +2,22 @@
 Functions, classes, decorators, and context managers to help wrap GMT modules.
 """
 from pygmt.helpers.decorators import (
-    check_data_input_order,
     deprecate_parameter,
     fmt_docstring,
     kwargs_to_strings,
     use_alias,
 )
-from pygmt.helpers.tempfile import GMTTempFile, tempfile_from_geojson, unique_name
+from pygmt.helpers.tempfile import (
+    GMTTempFile,
+    tempfile_from_geojson,
+    tempfile_from_image,
+    unique_name,
+)
 from pygmt.helpers.utils import (
     args_in_kwargs,
     build_arg_string,
     data_kind,
-    dummy_context,
     is_nonstr_iter,
     launch_external_viewer,
+    non_ascii_to_octal,
 )
