@@ -65,7 +65,7 @@ def grd2xyz(grid, output_type="pandas", outfile=None, **kwargs):
         **f** to start at 1 (Fortran-style counting). Alternatively, append
         **i** to write just the two columns *index* and *z*, where *index*
         is the 1-D indexing that GMT uses when referring to grid nodes.
-    {R}
+    {region}
         Adding ``region`` will select a subsection of the grid. If this
         subsection exceeds the boundaries of the grid, only the common region
         will be output.
@@ -80,7 +80,7 @@ def grd2xyz(grid, output_type="pandas", outfile=None, **kwargs):
         this by appending **+u**\ *unit*. For such grids, the area
         varies with latitude and also sees special cases for
         gridline-registered layouts at sides, corners, and poles.
-    {V}
+    {verbose}
     convention : str
         [*flags*].
         Write a 1-column ASCII [or binary] table. Output will be organized
@@ -111,12 +111,12 @@ def grd2xyz(grid, output_type="pandas", outfile=None, **kwargs):
         * **d** 8-byte floating point double precision
 
         Default format is scanline orientation of ASCII numbers: **TLa**.
-    {b}
-    {d}
-    {f}
-    {h}
-    {o}
-    {s}
+    {binary}
+    {nodata}
+    {coltypes}
+    {header}
+    {outcols}
+    {skiprows}
 
     Returns
     -------
@@ -139,9 +139,9 @@ def grd2xyz(grid, output_type="pandas", outfile=None, **kwargs):
     >>> # Create a pandas DataFrame with the xyz data from an input grid
     >>> xyz_dataframe = pygmt.grd2xyz(grid=grid, output_type="pandas")
     >>> xyz_dataframe.head(n=2)
-         lon    lat  elevation
-    0  10.25  24.75      903.5
-    1  10.75  24.75      820.0
+        lon   lat  elevation
+    0  10.0  25.0      863.0
+    1  10.5  25.0      985.5
     """
     if output_type not in ["numpy", "pandas", "file"]:
         raise GMTInvalidInput(
