@@ -1,12 +1,10 @@
 """
 grdimage - Plot grids or images.
 """
-import contextlib
-
 from pygmt.clib import Session
 from pygmt.helpers import (
     build_arg_string,
-    data_kind,
+    deprecate_parameter,
     fmt_docstring,
     kwargs_to_strings,
     use_alias,
@@ -16,20 +14,20 @@ __doctest_skip__ = ["grdimage"]
 
 
 @fmt_docstring
+@deprecate_parameter("bit_color", "bitcolor", "v0.10.0", remove_version="v0.12.0")
 @use_alias(
     A="img_out",
     B="frame",
     C="cmap",
     D="img_in",
     E="dpi",
-    G="bit_color",
+    G="bitcolor",
     I="shading",
     J="projection",
     M="monochrome",
     N="no_clip",
     Q="nan_transparent",
     R="region",
-    U="timestamp",
     V="verbose",
     n="interpolation",
     c="panel",
@@ -50,11 +48,11 @@ def grdimage(self, grid, **kwargs):
     instructions to derive intensities from the input data grid. Values outside
     this range will be clipped. Such intensity files can be created from the
     grid using :func:`pygmt.grdgradient` and, optionally, modified by
-    :gmt-docs:`grdmath.html` or :class:`pygmt.grdhisteq`. If GMT is built
-    with GDAL support, ``grid`` can be an image file (geo-referenced or not).
-    In this case the image can optionally be illuminated with the file
-    provided via the ``shading`` parameter. Here, if image has no coordinates
-    then those of the intensity file will be used.
+    :gmt-docs:`grdmath.html` or :class:`pygmt.grdhisteq`. Alternatively, pass
+    *image* which can be an image file (geo-referenced or not). In this case
+    the image can optionally be illuminated with the file provided via the
+    ``shading`` parameter. Here, if image has no coordinates then those of the
+    intensity file will be used.
 
     When using map projections, the grid is first resampled on a new
     rectangular grid with the same dimensions. Higher resolution images can
@@ -83,10 +81,7 @@ def grdimage(self, grid, **kwargs):
         :gmt-docs:`grdimage.html#grid-file-formats`).
     img_out : str
         *out_img*\[=\ *driver*].
-        Save an image in a raster format instead of PostScript. Use
-        extension .ppm for a Portable Pixel Map format which is the only
-        raster format GMT can natively write. For GMT installations
-        configured with GDAL support there are more choices: Append
+        Save an image in a raster format instead of PostScript. Append
         *out_img* to select the image file name and extension. If the
         extension is one of .bmp, .gif, .jpg, .png, or .tif then no driver
         information is required. For other output formats you must append
@@ -113,12 +108,13 @@ def grdimage(self, grid, **kwargs):
         to project a raw image (an image without referencing coordinates).
     dpi : int
         [**i**\|\ *dpi*].
-        Sets the resolution of the projected grid that will be created if a
-        map projection other than Linear or Mercator was selected [100]. By
-        default, the projected grid will be of the same size (rows and
-        columns) as the input file. Specify **i** to use the PostScript
-        image operator to interpolate the image at the device resolution.
-    bit_color : str
+        Set the resolution of the projected grid that will be created if a
+        map projection other than Linear or Mercator was selected [Default
+        is ``100`` dpi]. By default, the projected grid will be of the
+        same size (rows and columns) as the input file. Specify **i** to
+        use the PostScript image operator to interpolate the image at the
+        device resolution.
+    bitcolor : str
         *color*\ [**+b**\|\ **f**\].
         This parameter only applies when a resulting 1-bit image otherwise
         would consist of only two colors: black (0) and white (255). If so,
@@ -139,19 +135,22 @@ def grdimage(self, grid, **kwargs):
         :func:`pygmt.grdgradient` separately first. If we should derive
         intensities from another file than grid, specify the file with
         suitable modifiers [Default is no illumination]. **Note**: If the
-        input data is an *image* then an *intensfile* or constant *intensity*
-        must be provided.
+        input data represent an *image* then an *intensfile* or constant
+        *intensity* must be provided.
     {projection}
     monochrome : bool
         Force conversion to monochrome image using the (television) YIQ
         transformation. Cannot be used with ``nan_transparent``.
     no_clip : bool
-        Do not clip the image at the map boundary (only relevant for
-        non-rectangular maps).
-    nan_transparent : bool
+        Do **not** clip the image at the frame boundaries (only relevant
+        for non-rectangular maps) [Default is ``False``].
+    nan_transparent : bool or str
+        [**+z**\ *value*][*color*]
         Make grid nodes with z = NaN transparent, using the color-masking
         feature in PostScript Level 3 (the PS device must support PS Level
-        3).
+        3). If the input is a grid, use **+z** to select another grid value
+        than NaN. If input is instead an image, append an alternate *color* to
+        select another pixel value to be transparent [Default is ``"black"``].
     {region}
     {verbose}
     {panel}
@@ -175,17 +174,14 @@ def grdimage(self, grid, **kwargs):
     >>> fig.show()
     """
     kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
-    with Session() as lib:
-        file_context = lib.virtualfile_from_data(check_kind="raster", data=grid)
-        with contextlib.ExitStack() as stack:
-            # shading using an xr.DataArray
-            if kwargs.get("I") is not None and data_kind(kwargs["I"]) == "grid":
-                shading_context = lib.virtualfile_from_data(
-                    check_kind="raster", data=kwargs["I"]
-                )
-                kwargs["I"] = stack.enter_context(shading_context)
 
-            fname = stack.enter_context(file_context)
+    with Session() as lib:
+        with lib.virtualfile_from_data(
+            check_kind="raster", data=grid
+        ) as fname, lib.virtualfile_from_data(
+            check_kind="raster", data=kwargs.get("I"), required_data=False
+        ) as shadegrid:
+            kwargs["I"] = shadegrid
             lib.call_module(
                 module="grdimage", args=build_arg_string(kwargs, infile=fname)
             )
