@@ -11,6 +11,8 @@ from pygmt.helpers import (
 )
 from pygmt.io import load_dataarray
 
+__doctest_skip__ = ["sphinterpolate"]
+
 
 @fmt_docstring
 @use_alias(
@@ -38,14 +40,14 @@ def sphinterpolate(data, **kwargs):
     ----------
     data : str or {table-like}
         Pass in (x, y, z) or (longitude, latitude, elevation) values by
-        providing a file name to an ASCII data table, a 2D
+        providing a file name to an ASCII data table, a 2-D
         {table-classes}.
     outgrid : str or None
         The name of the output netCDF file with extension .nc to store the grid
         in.
-    {I}
-    {R}
-    {V}
+    {spacing}
+    {region}
+    {verbose}
 
     Returns
     -------
@@ -55,15 +57,25 @@ def sphinterpolate(data, **kwargs):
         - :class:`xarray.DataArray` if ``outgrid`` is not set
         - None if ``outgrid`` is set (grid output will be stored in file set by
           ``outgrid``)
+
+    Example
+    -------
+    >>> import pygmt
+    >>> # Load a table of Mars with longitude/latitude/radius columns
+    >>> mars_shape = pygmt.datasets.load_sample_data(name="mars_shape")
+    >>> # Perform Delaunay triangulation on the table data
+    >>> # to produce a grid with a 1 arc-degree spacing
+    >>> grid = pygmt.sphinterpolate(data=mars_shape, spacing=1, region="g")
     """
     with GMTTempFile(suffix=".nc") as tmpfile:
         with Session() as lib:
             file_context = lib.virtualfile_from_data(check_kind="vector", data=data)
             with file_context as infile:
-                if "G" not in kwargs:  # if outgrid is unset, output to tempfile
-                    kwargs.update({"G": tmpfile.name})
-                outgrid = kwargs["G"]
-                arg_str = " ".join([infile, build_arg_string(kwargs)])
-                lib.call_module("sphinterpolate", arg_str)
+                if (outgrid := kwargs.get("G")) is None:
+                    kwargs["G"] = outgrid = tmpfile.name  # output to tmpfile
+                lib.call_module(
+                    module="sphinterpolate",
+                    args=build_arg_string(kwargs, infile=infile),
+                )
 
         return load_dataarray(outgrid) if outgrid == tmpfile.name else None
