@@ -7,16 +7,15 @@ from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
     build_arg_string,
     data_kind,
-    deprecate_parameter,
     fmt_docstring,
     is_nonstr_iter,
     kwargs_to_strings,
+    non_ascii_to_octal,
     use_alias,
 )
 
 
 @fmt_docstring
-@deprecate_parameter("incols", "use_word", "v0.8.0", remove_version="v0.10.0")
 @use_alias(
     R="region",
     J="projection",
@@ -25,7 +24,6 @@ from pygmt.helpers import (
     D="offset",
     G="fill",
     N="no_clip",
-    U="timestamp",
     V="verbose",
     W="pen",
     a="aspatial",
@@ -68,6 +66,12 @@ def text_(
     - ``x``/``y``, and ``text``
     - ``position`` and ``text``
 
+    The text strings passed via the ``text`` parameter can contain ASCII
+    characters and non-ASCII characters defined in the ISOLatin1+ encoding
+    (i.e., IEC_8859-1), and the Symbol and ZapfDingbats character sets.
+    See :gmt-docs:`cookbook/octal-codes.html` for the full list of supported
+    non-ASCII characters.
+
     Full option list at :gmt-docs:`text.html`
 
     {aliases}
@@ -81,7 +85,7 @@ def text_(
         The x and y coordinates, or an array of x and y coordinates to plot
         the text.
     position : str
-        Sets reference point on the map for the text by using x, y
+        Set reference point on the map for the text by using x, y
         coordinates extracted from ``region`` instead of providing them
         through ``x``/``y``. Specify with a two-letter (order independent)
         code, chosen from:
@@ -120,22 +124,21 @@ def text_(
     clearance : str
         [*dx/dy*][**+to**\|\ **O**\|\ **c**\|\ **C**].
         Adjust the clearance between the text and the surrounding box
-        [Default is 15% of the font size]. Only used if ``pen`` or ``fill`` are
-        specified. Append the unit you want (*c* for cm, *i* for inch, or *p*
-        for point; if not given we consult :gmt-term:`PROJ_LENGTH_UNIT`)
-        or *%* for a percentage of the font size. Optionally, use modifier
-        **+t** to set the shape of the text box when using ``fill`` and/or
-        ``pen``. Append lower case **o** to get a straight rectangle
-        [Default is **o**]. Append upper case **O** to get a rounded
-        rectangle. In paragraph mode (*paragraph*) you can also append lower
-        case **c** to get a concave rectangle or append upper case **C**
-        to get a convex rectangle.
+        [Default is 15% of the font size]. Only used if ``pen`` or ``fill``
+        are specified. Append the unit you want (*c* for centimeters,
+        *i* for inches, or *p* for points; if not given we consult
+        :gmt-term:`PROJ_LENGTH_UNIT`) or *%* for a percentage of the font
+        size. Optionally, use modifier **+t** to set the shape of the text
+        box when using ``fill`` and/or ``pen``. Append lower case **o**
+        to get a straight rectangle [Default is **o**]. Append upper case
+        **O** to get a rounded rectangle. In paragraph mode (*paragraph*)
+        you can also append lower case **c** to get a concave rectangle or
+        append upper case **C** to get a convex rectangle.
     fill : str
-        Sets the shade or color used for filling the text box [Default is
-        no fill].
+        Set color for filling text boxes [Default is no fill].
     offset : str
         [**j**\|\ **J**]\ *dx*\[/*dy*][**+v**\[*pen*]].
-        Offsets the text from the projected (x, y) point by *dx*/\ *dy*
+        Offset the text from the projected (x, y) point by *dx*/\ *dy*
         [Default is ``"0/0"``].
         If *dy* is not specified then it is set equal to *dx*. Use **j** to
         offset the text away from the point instead (i.e., the text
@@ -145,11 +148,11 @@ def text_(
         point to the shifted point; append a pen to change the attributes
         for this line.
     pen : str
-        Sets the pen used to draw a rectangle around the text string
+        Set the pen used to draw a rectangle around the text string
         (see ``clearance``) [Default is ``"0.25p,black,solid"``].
     no_clip : bool
-        Do NOT clip text at map boundaries [Default is with clip].
-    {timestamp}
+        Do **not** clip text at the frame boundaries [Default is
+        ``False``].
     {verbose}
     {aspatial}
     {panel}
@@ -227,7 +230,9 @@ def text_(
 
     # Append text at last column. Text must be passed in as str type.
     if kind == "vectors":
-        extra_arrays.append(np.atleast_1d(text).astype(str))
+        extra_arrays.append(
+            np.vectorize(non_ascii_to_octal)(np.atleast_1d(text).astype(str))
+        )
 
     with Session() as lib:
         file_context = lib.virtualfile_from_data(
