@@ -3,16 +3,15 @@ Test the behaviour of the GMTDataArrayAccessor class.
 """
 import os
 import sys
+from pathlib import Path
 
 import pytest
 import xarray as xr
 from packaging.version import Version
-from pygmt import clib, which
+from pygmt import __gmt_version__, which
+from pygmt.datasets import load_earth_relief
 from pygmt.exceptions import GMTInvalidInput
 
-with clib.Session() as _lib:
-    gmt_version = Version(_lib.info["version"])
-
 
 def test_accessor_gridline_cartesian():
     """
@@ -76,13 +75,12 @@ def test_accessor_set_non_boolean():
 
 
 @pytest.mark.skipif(
-    gmt_version < Version("6.4.0"),
+    Version(__gmt_version__) < Version("6.4.0"),
     reason="Upstream bug fixed in https://github.com/GenericMappingTools/gmt/pull/6615",
 )
 @pytest.mark.xfail(
-    condition=sys.platform == "win32",
-    reason="PermissionError on Windows when deleting eraint_uvz.nc file; "
-    "see https://github.com/GenericMappingTools/pygmt/pull/2073",
+    condition=sys.platform == "win32" and Version(__gmt_version__) < Version("6.5.0"),
+    reason="Upstream bug fixed in https://github.com/GenericMappingTools/gmt/pull/7573",
 )
 def test_accessor_sliced_datacube():
     """
@@ -104,3 +102,32 @@ def test_accessor_sliced_datacube():
         assert grid.gmt.gtype == 1  # geographic coordinate type
     finally:
         os.remove(fname)
+
+
+def test_accessor_grid_source_file_not_exist():
+    """
+    Check that the accessor fallbacks to the default registration and gtype
+    when the grid source file (i.e., grid.encoding["source"]) doesn't exist.
+    """
+    # Load the 05m earth relief grid, which is stored as tiles
+    grid = load_earth_relief(
+        resolution="05m", region=[0, 5, -5, 5], registration="pixel"
+    )
+    # Registration and gtype are correct
+    assert grid.gmt.registration == 1
+    assert grid.gmt.gtype == 1
+    # The source grid file is defined but doesn't exist
+    assert grid.encoding["source"].endswith(".nc")
+    assert not Path(grid.encoding["source"]).exists()
+
+    # For a sliced grid, fallback to default registration and gtype,
+    # because the source grid file doesn't exist.
+    sliced_grid = grid[1:3, 1:3]
+    assert sliced_grid.gmt.registration == 0
+    assert sliced_grid.gmt.gtype == 0
+
+    # Still possible to manually set registration and gtype
+    sliced_grid.gmt.registration = 1
+    sliced_grid.gmt.gtype = 1
+    assert sliced_grid.gmt.registration == 1
+    assert sliced_grid.gmt.gtype == 1
