@@ -439,7 +439,9 @@ def test_virtualfile_from_data_required_z_matrix(array_func, kind):
     )
     data = array_func(dataframe)
     with clib.Session() as lib:
-        with lib.virtualfile_from_data(data=data, required_z=True) as vfile:
+        with lib.virtualfile_from_data(
+            data=data, required_z=True, check_kind="vector"
+        ) as vfile:
             with GMTTempFile() as outfile:
                 lib.call_module("info", f"{vfile} ->{outfile.name}")
                 output = outfile.read(keep_tabs=True)
@@ -461,7 +463,9 @@ def test_virtualfile_from_data_required_z_matrix_missing():
     data = np.ones((5, 2))
     with clib.Session() as lib:
         with pytest.raises(GMTInvalidInput):
-            with lib.virtualfile_from_data(data=data, required_z=True):
+            with lib.virtualfile_from_data(
+                data=data, required_z=True, check_kind="vector"
+            ):
                 pass
 
 
@@ -639,11 +643,11 @@ def test_virtualfile_from_vectors_pandas(dtypes):
     size = 13
     for dtype in dtypes:
         data = pd.DataFrame(
-            data=dict(
-                x=np.arange(size, dtype=dtype),
-                y=np.arange(size, size * 2, 1, dtype=dtype),
-                z=np.arange(size * 2, size * 3, 1, dtype=dtype),
-            )
+            data={
+                "x": np.arange(size, dtype=dtype),
+                "y": np.arange(size, size * 2, 1, dtype=dtype),
+                "z": np.arange(size * 2, size * 3, 1, dtype=dtype),
+            }
         )
         with clib.Session() as lib:
             with lib.virtualfile_from_vectors(data.x, data.y, data.z) as vfile:
