@@ -1,5 +1,5 @@
 """
-Tests for grdclip.
+Test pygmt.grdclip.
 """
 from pathlib import Path
 
@@ -29,7 +29,7 @@ def fixture_expected_grid():
             [1000.0, 1000.0, 571.5, 638.5],
             [555.5, 556.0, 580.0, 1000.0],
         ],
-        coords=dict(lon=[-52.5, -51.5, -50.5, -49.5], lat=[-18.5, -17.5, -16.5]),
+        coords={"lon": [-52.5, -51.5, -50.5, -49.5], "lat": [-18.5, -17.5, -16.5]},
         dims=["lat", "lon"],
     )
 
