@@ -1,5 +1,5 @@
 """
-Tests for grdcut.
+Test pygmt.grdcut.
 """
 import numpy as np
 import pytest
@@ -37,14 +37,14 @@ def fixture_expected_grid():
             [757.0, 570.5, 538.5, 524.0],
             [796.0, 886.0, 571.5, 638.5],
         ],
-        coords=dict(lon=[-52.5, -51.5, -50.5, -49.5], lat=[-19.5, -18.5, -17.5]),
+        coords={"lon": [-52.5, -51.5, -50.5, -49.5], "lat": [-19.5, -18.5, -17.5]},
         dims=["lat", "lon"],
     )
 
 
 def test_grdcut_dataarray_in_file_out(grid, expected_grid, region):
     """
-    grdcut an input DataArray, and output to a grid file.
+    Test grdcut on an input DataArray, and output to a grid file.
     """
     with GMTTempFile(suffix=".nc") as tmpfile:
         result = grdcut(grid, outgrid=tmpfile.name, region=region)
@@ -55,7 +55,7 @@ def test_grdcut_dataarray_in_file_out(grid, expected_grid, region):
 
 def test_grdcut_dataarray_in_dataarray_out(grid, expected_grid, region):
     """
-    grdcut an input DataArray, and output as DataArray.
+    Test grdcut on an input DataArray, and output as DataArray.
     """
     outgrid = grdcut(grid, region=region)
     assert isinstance(outgrid, xr.DataArray)
