@@ -1,5 +1,5 @@
 """
-Tests for grdfilter.
+Test pygmt.grdfilter.
 """
 from pathlib import Path
 
@@ -31,10 +31,10 @@ def fixture_expected_grid():
             [614.6496, 601.4992, 569.9743, 606.0966],
             [661.41003, 656.9681, 625.1668, 664.40204],
         ],
-        coords=dict(
-            lon=[-52.5, -51.5, -50.5, -49.5],
-            lat=[-19.5, -18.5, -17.5],
-        ),
+        coords={
+            "lon": [-52.5, -51.5, -50.5, -49.5],
+            "lat": [-19.5, -18.5, -17.5],
+        },
         dims=["lat", "lon"],
     )
 
