@@ -1,5 +1,5 @@
 """
-Tests for grdgradient.
+Test pygmt.grdgradient.
 """
 from pathlib import Path
 
@@ -30,10 +30,10 @@ def fixture_expected_grid():
             [-1.5880326e-03, -1.6113354e-03, -5.4624723e-04, -5.0047837e-04],
             [7.2569086e-04, 2.4801277e-04, 1.8859128e-05, -1.2269041e-03],
         ],
-        coords=dict(
-            lon=[-52.5, -51.5, -50.5, -49.5],
-            lat=[-19.5, -18.5, -17.5],
-        ),
+        coords={
+            "lon": [-52.5, -51.5, -50.5, -49.5],
+            "lat": [-19.5, -18.5, -17.5],
+        },
         dims=["lat", "lon"],
     )
 
