@@ -1,5 +1,5 @@
 """
-Tests for grdtrack.
+Test pygmt.grdtrack.
 """
 import os
 from pathlib import Path
@@ -51,7 +51,7 @@ def fixture_dataframe():
     Load a pandas DataFrame with points.
     """
     return pd.read_csv(
-        POINTS_DATA, sep=r"\s+", header=None, names=["longitude", "latitude"]
+        POINTS_DATA, delim_whitespace=True, header=None, names=["longitude", "latitude"]
     )
 
 
@@ -80,7 +80,7 @@ def test_grdtrack_input_csvfile_and_dataarray(dataarray, expected_array):
 
 def test_grdtrack_input_dataframe_and_ncfile(dataframe, expected_array):
     """
-    Run grdtrack by passing in a pandas.DataFrame and netcdf file as inputs.
+    Run grdtrack by passing in a pandas.DataFrame and netCDF file as inputs.
     """
     output = grdtrack(
         points=dataframe, grid="@static_earth_relief.nc", newcolname="bathymetry"
@@ -92,7 +92,7 @@ def test_grdtrack_input_dataframe_and_ncfile(dataframe, expected_array):
 
 def test_grdtrack_input_csvfile_and_ncfile_to_dataframe(expected_array):
     """
-    Run grdtrack by passing in a csv file and netcdf file as inputs with a
+    Run grdtrack by passing in a csv file and netCDF file as inputs with a
     pandas.DataFrame output.
     """
     output = grdtrack(points=POINTS_DATA, grid="@static_earth_relief.nc")
@@ -177,18 +177,3 @@ def test_grdtrack_set_points_and_profile(dataarray, dataframe):
     """
     with pytest.raises(GMTInvalidInput):
         grdtrack(grid=dataarray, points=dataframe, profile="BL/TR")
-
-
-def test_grdtrack_old_parameter_order(dataframe, dataarray, expected_array):
-    """
-    Run grdtrack with the old parameter order 'points, grid'.
-
-    This test should be removed in v0.9.0.
-    """
-    for points in (POINTS_DATA, dataframe):
-        for grid in ("@static_earth_relief.nc", dataarray):
-            with pytest.warns(expected_warning=FutureWarning) as record:
-                output = grdtrack(points, grid)
-                assert len(record) == 1
-                assert isinstance(output, pd.DataFrame)
-                npt.assert_allclose(np.array(output), expected_array)
