@@ -1,11 +1,12 @@
 """
-Tests the helper functions/classes/etc used in wrapping GMT.
+Test the helper functions/classes/etc used in wrapping GMT.
 """
 import os
 
 import numpy as np
 import pytest
 import xarray as xr
+from pygmt import Figure
 from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
     GMTTempFile,
@@ -57,6 +58,24 @@ def test_unique_name():
     assert len(names) == len(set(names))
 
 
+@pytest.mark.mpl_image_compare
+def test_non_ascii_to_octal():
+    """
+    Test support of non-ASCII characters.
+    """
+    fig = Figure()
+    fig.basemap(
+        region=[0, 10, 0, 5],
+        projection="X10c/5c",
+        frame=[
+            "xaf+lISOLatin1: ﬁ‰“”¥",
+            "yaf+lSymbol: αβ∇∋∈",
+            "WSen+tZapfDingbats: ①❷➂➍✦❝❞",
+        ],
+    )
+    return fig
+
+
 def test_kwargs_to_strings_fails():
     """
     Make sure it fails for invalid conversion types.
