@@ -1,5 +1,5 @@
 """
-Tests for makecpt.
+Test pygmt.makecpt.
 """
 import os
 from pathlib import Path
