@@ -6,10 +6,9 @@ from tempfile import TemporaryDirectory
 
 import pytest
 from pygmt.figure import SHOWED_FIGURES, Figure
+from pygmt.sphinx_gallery import PyGMTScraper
 
-pygmt_sphinx_gallery = pytest.importorskip(
-    "pygmt.sphinx_gallery", reason="Requires sphinx-gallery to be installed"
-)
+pytest.importorskip("sphinx-gallery", reason="Requires sphinx-gallery to be installed")
 pytest.importorskip("IPython", reason="Requires IPython to be installed")
 
 
@@ -26,7 +25,7 @@ def test_pygmtscraper():
         fig.show()
         assert len(SHOWED_FIGURES) == 1
         assert SHOWED_FIGURES[0] is fig
-        scraper = pygmt_sphinx_gallery.PyGMTScraper()
+        scraper = PyGMTScraper()
         with TemporaryDirectory(dir=os.getcwd()) as tmpdir:
             conf = {"src_dir": "meh"}
             fname = os.path.join(tmpdir, "meh.png")
