@@ -1,5 +1,5 @@
 """
-Tests wiggle.
+Test Figure.wiggle.
 """
 import numpy as np
 import pytest
