@@ -1,6 +1,6 @@
 # pylint: disable=unused-argument
 """
-Tests for x2sys_cross.
+Test pygmt.x2sys_cross.
 """
 import os
 from pathlib import Path
@@ -112,7 +112,7 @@ def test_x2sys_cross_input_two_dataframes(mock_x2sys_home):
         for i in range(2):
             np.random.seed(seed=i)
             track = pd.DataFrame(data=np.random.rand(10, 3), columns=("x", "y", "z"))
-            track["time"] = pd.date_range(start=f"2020-{i}1-01", periods=10, freq="ms")
+            track["time"] = pd.date_range(start=f"2020-{i}1-01", periods=10, freq="min")
             tracks.append(track)
 
         output = x2sys_cross(tracks=tracks, tag=tag, coe="e")
